<?php

/**
 * @file
 *
 * "Panel Pages" panels content pane. It shows users with permissions the
 * panel pages on the site, and provides links directly to the "content" tab.
 *
 */

$plugin = array(
  'single' => TRUE,
  'title' => t('Menus'),
  'defaults' => array('menus' => array()),
  'icon' => 'cog.png',
  'description' => t('A list of menus on the site.'),
  'category' => t('Total control'),
  'edit text' => t('Configure'),
);

/**
 * 'Admin title' callback for the content type.
 */
function total_control_menus_content_type_admin_title($subtype = NULL, $conf = NULL, $context = NULL) {
  return t('Menu overview');
}

/**
 * 'Admin info' callback for the content type.
 */
function total_control_menus_content_type_admin_info($subtype = NULL, $conf = NULL, $context = NULL) {
  $block = new stdClass();
  $block->title = t('Displays a list of Menus, with access to add and edit the links within.');

  return $block;
}

/**
 * Run-time rendering of the body of the block.
 */
function total_control_menus_content_type_render($subtype, $conf, $args, &$context) {
  $items = array();

  $menus = menu_get_menus();
  $header = array('page' => t('Menu'), 'options' => array('data' => t('Operations'), 'colspan' => 2));
  $rows = array();

  foreach ($menus as $menu_name => $menu) {
    if ($conf['menus'][$menu_name] === $menu_name) {
      $rows[] = array(
        'data' => array(
          t($menu),
          l(t('Edit menu'), 'admin/structure/menu/manage/' . $menu_name),
          l(t('Add new link'), 'admin/structure/menu/manage/' . $menu_name . '/add'),
        ),
      );
    }
  }

  // Build a link to the menu UI.
  if (user_access('administer menu')) {
    $link = l(t('Menu administration'), 'admin/structure/menus');
  }

  $block = new stdClass();
  $block->title = t('Menus');
  $block->module = t('total_control');
  // TODO
  $block->content = theme('total_control_menus', array('header' => $header, 'rows' => $rows, 'link' => $link));

  return $block;

}

/**
 * 'Edit form' callback for the content type.
 */
function total_control_menus_content_type_edit_form($form, &$form_state) {
  $conf = $form_state['conf'];

  $menus = menu_get_menus();
  foreach ($menus as $machine => $name) {
    if (!in_array($machine, array('management', 'user-menu', 'devel'))) {
      $menu_defaults[$machine] = $machine;
    }
  }
  $form['menus'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Show links for the following menus on the dashboard'),
    '#options' => $menus,
    '#default_value' => ($conf['menus'])? $conf['menus'] : $menu_defaults,
  );

  return $form;
}

/**
 * 'Edit form' submit callback for the content type.
 */
function total_control_menus_content_type_edit_form_submit($form, &$form_state) {
  foreach (array_keys($form_state['plugin']['defaults']) as $key) {
    $form_state['conf'][$key] = $form_state['values'][$key];
  }
}
